@@ -30,6 +30,7 @@
 package SNMP::Info::IEEE802dot3ad;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Aggregate;
 
@@ -41,9 +42,9 @@ use SNMP::Info::Aggregate;
   agg_ports_lag
 /;
 
-use vars qw/$VERSION %MIBS %FUNCS %GLOBALS %MUNGE/;
+our ($VERSION, %MIBS, %FUNCS, %GLOBALS, %MUNGE);
 
-$VERSION = '3.53';
+$VERSION = '3.71';
 
 %MIBS = (
   %SNMP::Info::Aggregate::MIBS,
@@ -64,7 +65,8 @@ sub agg_ports_lag {
   my $dev = shift;
 
   # TODO: implement partial
-  my $ports  = $dev->ad_lag_ports;
+  my $ports  = $dev->ad_lag_ports();
+  my $index  = $dev->bp_index() || {};
 
   return {} unless ref {} eq ref $ports and scalar keys %$ports;
 
@@ -73,8 +75,17 @@ sub agg_ports_lag {
     my $idx = $m;
     my $portlist = $ports->{$m};
     next unless $portlist;
+
+    # While dot3adAggTable is indexed by ifIndex, the portlist is indexed
+    # with a dot1dBasePort, so we need to use dot1dBasePortIfIndex to map to
+    # the ifIndex. If we don't have dot1dBasePortIfIndex assume
+    # dot1dBasePort = ifIndex
     for ( my $i = 0; $i <= scalar(@$portlist); $i++ ) {
-      $ret->{$i+1} = $idx if ( @$portlist[$i] );
+      my $ifindex = $i+1;
+      if ( exists($index->{$i+1}) and defined($index->{$i+1}) ) {
+        $ifindex = $index->{$i+1};
+      }
+      $ret->{$ifindex} = $idx if ( @$portlist[$i] );
     }
   }
 
@@ -95,14 +106,14 @@ SNMP::Info Developers
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $info = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myrouter',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class = $info->class();
