@@ -1,5 +1,4 @@
 # SNMP::Info::Layer2::HP - SNMP Interface to HP ProCurve Switches
-# $Id$
 #
 # Copyright (c) 2008-2009 Max Baker changes from version 0.8 and beyond.
 #
@@ -33,6 +32,7 @@
 package SNMP::Info::Layer2::HP;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer3;
 use SNMP::Info::MAU;
@@ -41,31 +41,33 @@ use SNMP::Info::Aggregate 'agg_ports_ifstack';
 
 @SNMP::Info::Layer2::HP::ISA = qw/
     SNMP::Info::Aggregate
-    SNMP::Info::Layer3 
-    SNMP::Info::MAU 
-    SNMP::Info::CDP 
+    SNMP::Info::Layer3
+    SNMP::Info::MAU
+    SNMP::Info::CDP
     Exporter
 /;
 @SNMP::Info::Layer2::HP::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %PORTSTAT %MODEL_MAP %MUNGE/;
+our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %PORTSTAT, %MODEL_MAP, %MUNGE);
 
-$VERSION = '3.53';
+$VERSION = '3.71';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
     %SNMP::Info::MAU::MIBS,
     %SNMP::Info::CDP::MIBS,
     %SNMP::Info::Aggregate::MIBS,
-    'RFC1271-MIB'    => 'logDescription',
-    'HP-ICF-OID'     => 'hpSwitch4000',
-    'STATISTICS-MIB' => 'hpSwitchCpuStat',
-    'NETSWITCH-MIB'  => 'hpMsgBufFree',
-    'CONFIG-MIB'     => 'hpSwitchConfig',
-    'HP-ICF-CHASSIS' => 'hpicfSensorObjectId',
-    'HP-ICF-BRIDGE'  => 'hpicfBridgeRstpForceVersion',
-    'HP-ICF-POE-MIB' => 'hpicfPoePethPsePortCurrent',
-    'SEMI-MIB'       => 'hpHttpMgSerialNumber',
+    'RFC1271-MIB'            => 'logDescription',
+    'HP-ICF-OID'             => 'hpSwitch4000',
+    'STATISTICS-MIB'         => 'hpSwitchCpuStat',
+    'NETSWITCH-MIB'          => 'hpMsgBufFree',
+    'CONFIG-MIB'             => 'hpSwitchConfig',
+    'HP-ICF-CHASSIS'         => 'hpicfSensorObjectId',
+    'HP-ICF-BRIDGE'          => 'hpicfBridgeRstpForceVersion',
+    'HP-ICF-POE-MIB'         => 'hpicfPoePethPsePortCurrent',
+    'SEMI-MIB'               => 'hpHttpMgSerialNumber',
+    'HP-SWITCH-PL-MIB'       => 'hpSwitchProliant',
+    'BLADETYPE4-NETWORK-MIB' => 'hpProLiant-GbE2c-InterconnectSwitch',
 );
 
 %GLOBALS = (
@@ -105,7 +107,7 @@ $VERSION = '3.53';
     'hp_s_oid'    => 'hpicfSensorObjectId',
     'hp_s_name'   => 'hpicfSensorDescr',
     'hp_s_status' => 'hpicfSensorStatus',
-    
+
     # HP-ICF-POE-MIB
     'peth_port_power'   => 'hpicfPoePethPsePortPower',
 );
@@ -121,7 +123,7 @@ $VERSION = '3.53';
 
 
 # Model map, reverse sorted by common model name (sort -k2 -r)
-# Potential sources for model information: http://www.hp.com/rnd/software/switches.htm or HP-ICF-OID MIB 
+# Potential sources for model information: http://www.hp.com/rnd/software/switches.htm or HP-ICF-OID MIB
 %MODEL_MAP = (
     'J8131A' => 'WAP-420-WW',
     'J8130A' => 'WAP-420-NA',
@@ -156,6 +158,12 @@ $VERSION = '3.53';
     'J8771A' => '4202vl-48G',
     'J4865A' => '4108GL',
     'J4887A' => '4104GL',
+    'JL074A' => '3810M-48G-PoE+',
+    'JL072A' => '3810M-48G',
+    'JL076A' => '3810M-40G-8SR-PoE+',
+    'JL073A' => '3810M-24G-PoE+',
+    'JL071A' => '3810M-24G',
+    'JL075A' => '3810M-16SFP+',
     'J9588A' => '3800-48G-PoE+-4XG',
     'J9574A' => '3800-48G-PoE+-4SFP+',
     'J9586A' => '3800-48G-4XG',
@@ -175,6 +183,23 @@ $VERSION = '3.53';
     'J4905A' => '3400cl-24G',
     'J4815A' => '3324XL',
     'J4851A' => '3124',
+    'JL322A' => '2930M-48G-PoE+',
+    'JL321A' => '2930M-48G',
+    'JL323A' => '2930M-40G-8SR-PoE+',
+    'JL320A' => '2930M-24G-PoE+',
+    'JL324A' => '2930M-24G-8SR-PoE+',
+    'JL319A' => '2930M-24G',
+    'JL258A' => '2930F-8G-PoE+-2SFP+',
+    'JL558A' => '2930F-48G-PoE+-4SFP+-740W',
+    'JL557A' => '2930F-48G-PoE+-4SFP-740W',
+    'JL256A' => '2930F-48G-PoE+-4SFP+',
+    'JL262A' => '2930F-48G-PoE+-4SFP',
+    'JL254A' => '2930F-48G-4SFP+',
+    'JL260A' => '2930F-48G-4SFP',
+    'JL255A' => '2930F-24G-PoE+-4SFP+',
+    'JL261A' => '2930F-24G-PoE+-4SFP',
+    'JL253A' => '2930F-24G-4SFP+',
+    'JL259A' => '2930F-24G-4SFP',
     'J9729A' => '2920-48G-PoE+',
     'J9729A' => '2920-48G-PoE+',
     'J9728A' => '2920-48G',
@@ -214,6 +239,11 @@ $VERSION = '3.53';
     'J9086A' => '2610-24/12PWR',
     'J9085A' => '2610-24',
     'J8762A' => '2600-8-PWR',
+    'JL357A' => '2540-48G-PoE+-4SFP+',
+    'JL355A' => '2540-48G-4SFP+',
+    'JL356A' => '2540-24G-PoE+-4SFP+',
+    'JL354A' => '2540-24G-4SFP+',
+    'JL070A' => '2530-8-PoE+ Internal PS',
     'J9780A' => '2530-8-PoE+',
     'J9774A' => '2530-8G-PoEP',
     'J9777A' => '2530-8G',
@@ -285,7 +315,7 @@ sub os_ver {
     return;
 }
 
-# Regular managed ProCurve switches have the serial num in entity mib, 
+# Regular managed ProCurve switches have the serial num in entity mib,
 # the web-managed models in the semi mib (hphttpmanageable).
 sub serial {
     my $hp = shift;
@@ -303,7 +333,7 @@ sub model {
     my $model = &SNMP::translateObj($id);
     return $id unless defined $model;
 
-    $model =~ s/^hpswitch//i;
+    $model =~ s/^(hp|aruba)switch//i;
 
     return defined $MODEL_MAP{$model} ? $MODEL_MAP{$model} : $model;
 }
@@ -565,14 +595,14 @@ Max Baker
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $hp = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $hp->class();
@@ -580,15 +610,15 @@ Max Baker
 
 =head1 DESCRIPTION
 
-Provides abstraction to the configuration information obtainable from a 
-HP ProCurve Switch via SNMP. 
+Provides abstraction to the configuration information obtainable from a
+HP ProCurve Switch via SNMP.
 
 Note:  Some HP Switches will connect via SNMP version 1, but a lot of config
 data will not be available.  Make sure you try and connect with Version 2
 first, and then fail back to version 1.
 
 For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above. 
+after determining a more specific class using the method above.
 
  my $hp = new SNMP::Info::Layer2::HP(...);
 
@@ -624,6 +654,14 @@ Included in V2 mibs from Cisco
 
 =item F<HP-ICF-POE-MIB>
 
+=item F<HP-ICF-CHASSIS>
+
+=item F<SEMI-MIB>
+
+=item F<HP-SWITCH-PL-MIB>
+
+=item F<BLADETYPE4-NETWORK-MIB>
+
 =back
 
 The last four MIBs listed are from HP and can be found at
@@ -836,7 +874,7 @@ to a hash.
 
 =over 4
 
-=item $hp->interfaces() 
+=item $hp->interfaces()
 
 Uses $hp->i_description()
 
@@ -893,7 +931,7 @@ Munge for c_id which handles CDP and LLDP.
 These are methods that provide SNMP set functionality for overridden methods
 or provide a simpler interface to complex set operations.  See
 L<SNMP::Info/"SETTING DATA VIA SNMP"> for general information on set
-operations. 
+operations.
 
 =over
 
