@@ -1,5 +1,4 @@
 # SNMP::Info::Layer3::Contivity
-# $Id$
 #
 # Copyright (c) 2010 Eric Miller
 # All rights reserved.
@@ -31,36 +30,32 @@
 package SNMP::Info::Layer3::Contivity;
 
 use strict;
+use warnings;
 use Exporter;
-use SNMP::Info;
 use SNMP::Info::Layer3;
-use SNMP::Info::Entity;
 
 @SNMP::Info::Layer3::Contivity::ISA
-    = qw/SNMP::Info SNMP::Info::Layer3 SNMP::Info::Entity Exporter/;
+    = qw/SNMP::Info::Layer3 Exporter/;
 @SNMP::Info::Layer3::Contivity::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %FUNCS %MIBS %MUNGE/;
+our ($VERSION, %GLOBALS, %FUNCS, %MIBS, %MUNGE);
 
-$VERSION = '3.31';
+$VERSION = '3.71';
 
 %MIBS = (
-    %SNMP::Info::MIBS, %SNMP::Info::Layer3::MIBS, %SNMP::Info::Entity::MIBS,
+    %SNMP::Info::Layer3::MIBS,
 );
 
 %GLOBALS = (
-    %SNMP::Info::GLOBALS, %SNMP::Info::Layer3::GLOBALS,
-    %SNMP::Info::Entity::GLOBALS,
+    %SNMP::Info::Layer3::GLOBALS,
 );
 
 %FUNCS = (
-    %SNMP::Info::FUNCS, %SNMP::Info::Layer3::FUNCS,
-    %SNMP::Info::Entity::FUNCS,
+  %SNMP::Info::Layer3::FUNCS,
 );
 
 %MUNGE = (
-    %SNMP::Info::MUNGE, %SNMP::Info::Layer3::MUNGE,
-    %SNMP::Info::Entity::MUNGE,
+  %SNMP::Info::Layer3::MUNGE,
 );
 
 sub layers {
@@ -101,7 +96,7 @@ sub mac {
     my $i_mac     = $contivity->i_mac();
 
     # Return Interface MAC
-    foreach my $entry ( keys %$i_mac ) {
+    foreach my $entry ( sort keys %$i_mac ) {
         my $sn = $i_mac->{$entry};
         next unless $sn;
         return $sn;
@@ -171,14 +166,14 @@ Eric Miller
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $contivity = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class = $contivity->class();
@@ -187,23 +182,14 @@ Eric Miller
 =head1 DESCRIPTION
 
 Abstraction subclass for Avaya/Nortel VPN Routers (formerly Contivity
-Extranet Switch).  
-
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above. 
-
- my $contivity = new SNMP::Info::Layer3::Contivity(...);
+Extranet Switch).
 
 =head2 Inherited Classes
 
 =over
 
-=item SNMP::Info
-
 =item SNMP::Info::Layer3
 
-=item SNMP::Info::Entity
-
 =back
 
 =head2 Required MIBs
@@ -212,12 +198,8 @@ after determining a more specific class using the method above.
 
 =item Inherited Classes' MIBs
 
-See L<SNMP::Info/"Required MIBs"> for its own MIB requirements.
-
 See L<SNMP::Info::Layer3/"Required MIBs"> for its own MIB requirements.
 
-See L<SNMP::Info::Entity/"Required MIBs"> for its own MIB requirements.
-
 =back
 
 =head1 GLOBALS
@@ -238,7 +220,7 @@ Returns the chassis name.
 
 =item $contivity->os()
 
-Returns C<'CES'>
+Returns C<'contivity'>
 
 =item $contivity->os_ver()
 
@@ -267,18 +249,10 @@ layers.
 
 =back
 
-=head2 Globals imported from SNMP::Info
-
-See documentation in L<SNMP::Info/"GLOBALS"> for details.
-
 =head2 Globals imported from SNMP::Info::Layer3
 
 See documentation in L<SNMP::Info::Layer3/"GLOBALS"> for details.
 
-=head2 Globals imported from SNMP::Info::Entity
-
-See documentation in L<SNMP::Info::Entity/"GLOBALS"> for details.
-
 =head1 TABLE METHODS
 
 These are methods that return tables of information in the form of a reference
@@ -299,16 +273,8 @@ Interface Name field.  Skips loopback and tunnel interfaces.
 
 =back
 
-=head2 Table Methods imported from SNMP::Info
-
-See documentation in L<SNMP::Info/"TABLE METHODS"> for details.
-
 =head2 Table Methods imported from SNMP::Info::Layer3
 
 See documentation in L<SNMP::Info::Layer3/"TABLE METHODS"> for details.
 
-=head2 Table Methods imported from SNMP::Info::Entity
-
-See documentation in L<SNMP::Info::Entity/"TABLE METHODS"> for details.
-
 =cut
