@@ -1,5 +1,4 @@
 # SNMP::Info::Layer3::Enterasys - SNMP Interface to Enterasys devices
-# $Id$
 #
 # Copyright (c) 2008 Eric Miller
 # All rights reserved.
@@ -31,41 +30,41 @@
 package SNMP::Info::Layer3::Enterasys;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::MAU;
-use SNMP::Info::LLDP;
 use SNMP::Info::CDP;
 use SNMP::Info::Layer3;
 
-@SNMP::Info::Layer3::Enterasys::ISA = qw/SNMP::Info::MAU SNMP::Info::LLDP
+@SNMP::Info::Layer3::Enterasys::ISA = qw/SNMP::Info::MAU
     SNMP::Info::CDP SNMP::Info::Layer3
     Exporter/;
 @SNMP::Info::Layer3::Enterasys::EXPORT_OK = qw//;
 
 our ($VERSION, $DEBUG, %GLOBALS, %FUNCS, $INIT, %MIBS, %MUNGE);
 
-$VERSION = '3.68';
+$VERSION = '3.71';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS, %SNMP::Info::CDP::MIBS,
-    %SNMP::Info::LLDP::MIBS, %SNMP::Info::MAU::MIBS,
+    %SNMP::Info::MAU::MIBS,
     'ENTERASYS-OIDS-MIB' => 'etsysOidDevice',
 );
 
 %GLOBALS = (
     %SNMP::Info::Layer3::GLOBALS, %SNMP::Info::CDP::GLOBALS,
-    %SNMP::Info::LLDP::GLOBALS,   %SNMP::Info::MAU::GLOBALS,
+    %SNMP::Info::MAU::GLOBALS,
     'mac' => 'dot1dBaseBridgeAddress',
 );
 
 %FUNCS = (
     %SNMP::Info::Layer3::FUNCS, %SNMP::Info::CDP::FUNCS,
-    %SNMP::Info::LLDP::FUNCS,   %SNMP::Info::MAU::FUNCS,
+    %SNMP::Info::MAU::FUNCS,
 );
 
 %MUNGE = (
     %SNMP::Info::Layer3::MUNGE, %SNMP::Info::CDP::MUNGE,
-    %SNMP::Info::LLDP::MUNGE,   %SNMP::Info::MAU::MUNGE,
+    %SNMP::Info::MAU::MUNGE,
 );
 
 sub model {
@@ -267,7 +266,7 @@ Eric Miller
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
-                          Version     => 1
+                          Version     => 2
                         )
     or die "Can't connect to DestHost.\n";
 
@@ -280,19 +279,12 @@ Eric Miller
 Provides abstraction to the configuration information obtainable from an
 Enterasys device through SNMP.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above.
-
-my $enterasys = new SNMP::Info::Layer3::Enterasys(...);
-
 =head2 Inherited Classes
 
 =over
 
 =item SNMP::Info::MAU
 
-=item SNMP::Info::LLDP
-
 =item SNMP::Info::CDP
 
 =item SNMP::Info::Layer3
@@ -311,8 +303,6 @@ my $enterasys = new SNMP::Info::Layer3::Enterasys(...);
 
 See L<SNMP::Info::MAU/"Required MIBs"> for its MIB requirements.
 
-See L<SNMP::Info::LLDP/"Required MIBs"> for its MIB requirements.
-
 See L<SNMP::Info::CDP/"Required MIBs"> for its MIB requirements.
 
 See L<SNMP::Info::Layer3/"Required MIBs"> for its MIB requirements.
@@ -352,10 +342,6 @@ Returns base mac
 
 See documentation in L<SNMP::Info::MAU/"GLOBALS"> for details.
 
-=head2 Globals imported from SNMP::Info::LLDP
-
-See documentation in L<SNMP::Info::LLDP/"GLOBALS"> for details.
-
 =head2 Globals imported from SNMP::Info::CDP
 
 See documentation in L<SNMP::Info::CDP/"GLOBALS"> for details.
@@ -427,10 +413,6 @@ supply a partial value of zero which means no time filter.
 
 See documentation in L<SNMP::Info::MAU/"TABLE METHODS"> for details.
 
-=head2 Table Methods imported from SNMP::Info::LLDP
-
-See documentation in L<SNMP::Info::LLDP/"TABLE METHODS"> for details.
-
 =head2 Table Methods imported from SNMP::Info::CDP
 
 See documentation in L<SNMP::Info::CDP/"TABLE METHODS"> for details.
